@@ -27,7 +27,7 @@
 
 class MainWidget;
 
-class KAddressBookPart: public KParts::ReadOnlyPart
+class KAddressBookPart : public KParts::ReadOnlyPart
 {
     Q_OBJECT
 
@@ -41,8 +41,8 @@ public Q_SLOTS:
     void updateQuickSearchText();
 
 protected:
-    bool openFile() Q_DECL_OVERRIDE;
-    void guiActivateEvent(KParts::GUIActivateEvent *) Q_DECL_OVERRIDE;
+    bool openFile() override;
+    void guiActivateEvent(KParts::GUIActivateEvent *) override;
     void initAction();
 private:
     MainWidget *mMainWidget;
