@@ -36,11 +36,12 @@ class KAddressBookApplication : public KontactInterface::PimUniqueApplication
 {
 public:
     KAddressBookApplication(int &argc, char **argv[])
-        : KontactInterface::PimUniqueApplication(argc, argv),
-          mMainWindow(nullptr)
+        : KontactInterface::PimUniqueApplication(argc, argv)
+        , mMainWindow(nullptr)
     {
     }
-    int activate(const QStringList &arguments, const QString &) Q_DECL_OVERRIDE;
+
+    int activate(const QStringList &arguments, const QString &) override;
 
 private:
     MainWindow *mMainWindow;
@@ -65,6 +66,7 @@ int main(int argc, char **argv)
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     KAddressBookApplication app(argc, &argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    app.setDesktopFileName(QStringLiteral("org.kde.kaddressbook"));
     KCrash::initialize();
     KLocalizedString::setApplicationDomain("kaddressbook");
 
